// LAMESettings.cpp : implementation file
//

#include "stdafx.h"
#include "LAMESettings.h"
#include "afxdialogex.h"
#include <memory>
#include "resource.h"
#include "lame.h"

// CLAMESettings dialog

IMPLEMENT_DYNAMIC(CLAMESettings, CDialog)

CLAMESettings::CLAMESettings(LAME_Settings& s, CWnd* pParent /*=NULL*/)
	: CDialog(IDD_LAMESETTINGS, pParent), settings(s)
{
}

CLAMESettings::~CLAMESettings()
{
}

void CLAMESettings::DoDataExchange(CDataExchange* pDX)
{
	int ctrlValue = 0;

	CDialog::DoDataExchange(pDX);

	DDX_Control(pDX, IDC_COMBO_TYPE, m_Combo_Type);
	DDX_Control(pDX, IDC_COMBO_VBR_QUALITY, m_Combo_VBR_Quality);
	DDX_Control(pDX, IDC_COMBO_CHANNELS, m_Combo_Channels);
	DDX_Control(pDX, IDC_COMBO_SAMPLE_RATE, m_Combo_Sample_Rate);
	DDX_Control(pDX, IDC_COMBO_BIT_RATE, m_Combo_Bit_Rate);
	DDX_Control(pDX, IDC_COMBO_QUALITY, m_Combo_Quality);

	if (!pDX->m_bSaveAndValidate)
	{
		// Load from settings into the dialog
		// Initialize combo boxes
		LoadCombo(m_Combo_Type, IDS_TYPE_AUTO, IDS_TYPE_VARIABLE_BIT_RATE);
		LoadCombo(m_Combo_VBR_Quality, IDS_VBR_1, IDS_VBR_10);
		LoadCombo(m_Combo_Channels, IDS_CHANNELS_AUTO, IDS_CHANNELS_JOINT_STEREO);
		LoadCombo(m_Combo_Sample_Rate, IDS_SAMPLE_RATE_8000, IDS_SAMPLE_RATE_48000);
		LoadCombo(m_Combo_Bit_Rate, IDS_BIT_RATE_16, IDS_BIT_RATE_320);
		LoadCombo(m_Combo_Quality, IDS_QUALITY_1, IDS_QUALITY_10);

		// k_stereoMode
		switch (settings.stereoMode) {
		default:			ctrlValue = 0;	break;
		case MONO:			ctrlValue = 1;	break;
		case STEREO:		ctrlValue = 2;	break;
		case JOINT_STEREO:	ctrlValue = 3;	break;
		}
		m_Combo_Channels.SetCurSel(ctrlValue);

		//	k_vbrMode
		switch (settings.vbrMode) {
		default:		ctrlValue = 0;	break;
		case vbr_off:	ctrlValue = 1;	break;
		case vbr_abr:	ctrlValue = 2;	break;
		case vbr_rh:	ctrlValue = 3;	break;
		}
		m_Combo_Type.SetCurSel(ctrlValue);

		// k_sampleRate
		switch (settings.sampleRate) {
		default:	ctrlValue = 7;	break;
		case 8000:	ctrlValue = 0;	break;
		case 11025:	ctrlValue = 1;	break;
		case 12000:	ctrlValue = 2;	break;
		case 16000:	ctrlValue = 3;	break;
		case 22050:	ctrlValue = 4;	break;
		case 24000:	ctrlValue = 5;	break;
		case 32000:	ctrlValue = 6;	break;
		case 44100:	ctrlValue = 7;	break;
		case 48000:	ctrlValue = 8;	break;
		}
		m_Combo_Sample_Rate.SetCurSel(ctrlValue);

		//	k_vbrQuality
		m_Combo_VBR_Quality.SetCurSel(settings.vbrQuality);

		//	k_bitRate
		static unsigned short gBitRates[] = { 16, 32, 40, 48, 56, 64, 80, 96, 112, 128, 160, 192, 256, 320 };
		for (ctrlValue = 0; ctrlValue < (sizeof(gBitRates) / sizeof(gBitRates[0])); ctrlValue++) {
			if (gBitRates[ctrlValue] == settings.bitRate) {
				m_Combo_Bit_Rate.SetCurSel(ctrlValue);
				break;
			}
		}

		//	k_quality
		m_Combo_Quality.SetCurSel(settings.quality);
	}
	else
	{
		//	k_vbrMode
		switch (m_Combo_Type.GetCurSel()) {
		default: ctrlValue = 0;	break;
		case 1:	ctrlValue = vbr_off;	break;
		case 2:	ctrlValue = vbr_abr;	break;
		case 3: ctrlValue = vbr_rh;	break;
		}
		settings.vbrMode = (vbr_mode)ctrlValue;

		//	k_vbrQuality
		ctrlValue = m_Combo_VBR_Quality.GetCurSel();
		if (ctrlValue == CB_ERR)
			ctrlValue = 0;
		settings.vbrQuality = ctrlValue;

		// k_stereoMode
		switch (m_Combo_Channels.GetCurSel()) {
		default:ctrlValue = 0;	break;
		case 1: ctrlValue = MONO;	break;
		case 2: ctrlValue = STEREO;	break;
		case 3: ctrlValue = JOINT_STEREO;	break;
		}
		settings.stereoMode = (MPEG_mode)ctrlValue;

		// k_sampleRate
		switch (m_Combo_Sample_Rate.GetCurSel()) {
		default:	ctrlValue = 0;	break;
		case 0: ctrlValue = 8000; break;
		case 1: ctrlValue = 11025; break;
		case 2: ctrlValue = 12000; break;
		case 3: ctrlValue = 16000; break;
		case 4: ctrlValue = 22050; break;
		case 5: ctrlValue = 24000; break;
		case 6: ctrlValue = 32000; break;
		case 7: ctrlValue = 44100; break;
		case 8: ctrlValue = 48000; break;
		}
		settings.sampleRate = ctrlValue;

		//	k_bitRate
		static unsigned short gBitRates[] = { 16, 32, 40, 48, 56, 64, 80, 96, 112, 128, 160, 192, 256, 320 };
		ctrlValue = m_Combo_Bit_Rate.GetCurSel();
		if (ctrlValue >= 0 && ctrlValue < _countof(gBitRates))
			ctrlValue = gBitRates[ctrlValue];
		else
			ctrlValue = 128;
		settings.bitRate = ctrlValue;

		//	k_quality
		ctrlValue = m_Combo_Quality.GetCurSel();
		if (ctrlValue == CB_ERR)
			ctrlValue = 0;
		settings.quality = ctrlValue;
	}
}

static HRESULT ShowSettingsInternal(LAME_Settings& ls, HWND hParent)
{
	CWnd* pParent = nullptr;
	if(hParent)
		pParent = CWnd::FromHandle(hParent);

	CLAMESettings dialog(ls, pParent);
	BOOL bSuccess;
	HRESULT result = S_OK;

	// Create the dialog
	bSuccess = dialog.Create(IDD_LAMESETTINGS);
	if (!bSuccess)
		return E_FAIL;

	// Show the window
	dialog.ShowWindow(SW_SHOW);

	// Run a modal loop for it
	int res = dialog.RunModalLoop();
	switch (res) {
	case IDOK: result = S_OK; break;
	case IDCANCEL: result = E_ABORT; break;
	default: result = E_UNEXPECTED; break;
	}
	
	// Hide the window
	dialog.ShowWindow(SW_HIDE);
	//dialog.DestroyWindow();

	return result;
}

HRESULT ShowSettings(LAME_Settings* ls, HWND hParent)
{
	HRESULT hr = S_OK;

	// Sanity check
	if (!ls)
		return E_INVALIDARG;

	AFX_MANAGE_STATE(AfxGetStaticModuleState());

	try {
		hr = ShowSettingsInternal(*ls,hParent);
	}
	catch (COleException* ex)
	{
		hr = ex->m_sc;
		ex->Delete();
	}
	catch (CException* ex)
	{
		ex->Delete();
	}
	catch (std::bad_alloc&)
	{
		hr = E_OUTOFMEMORY;
	}
	catch (...)
	{
		hr = E_UNEXPECTED;
	}

	return hr;
}

// WM_COMMAND wNotifyCode: CBN_xxx, wID: IDC_COMBO_xxx
BEGIN_MESSAGE_MAP(CLAMESettings, CDialog)
	ON_BN_CLICKED(IDOK, &CLAMESettings::OnBnClickedOk)
	ON_BN_CLICKED(IDCANCEL, &CLAMESettings::OnBnClickedCancel)
	ON_CONTROL(CBN_SELCHANGE, IDC_COMBO_TYPE, &CLAMESettings::OnTypeChanged)
	ON_CONTROL(CBN_SELCHANGE, IDC_COMBO_VBR_QUALITY, &CLAMESettings::OnVBRQualityChanged)
	ON_CONTROL(CBN_SELCHANGE, IDC_COMBO_CHANNELS, &CLAMESettings::OnChannelsChanged)
	ON_CONTROL(CBN_SELCHANGE, IDC_COMBO_SAMPLE_RATE, &CLAMESettings::OnSampleRateChanged)
	ON_CONTROL(CBN_SELCHANGE, IDC_COMBO_BIT_RATE, &CLAMESettings::OnBitRateChanged)
	ON_CONTROL(CBN_SELCHANGE, IDC_COMBO_QUALITY, &CLAMESettings::OnQualityChanged)
END_MESSAGE_MAP()

// CLAMESettings message handlers


void CLAMESettings::OnBnClickedOk()
{
	// End the modal loop
	EndModalLoop(IDOK);

	// TODO: Add your control notification handler code here
	CDialog::OnOK();
}


void CLAMESettings::OnBnClickedCancel()
{
	// End the modal loop
	EndModalLoop(IDCANCEL);

	// TODO: Add your control notification handler code here
	CDialog::OnCancel();
}


BOOL CLAMESettings::OnInitDialog()
{
	CDialog::OnInitDialog();

	// TODO:  Add extra initialization here

	return TRUE;  // return TRUE unless you set the focus to a control
				  // EXCEPTION: OCX Property Pages should return FALSE
}

void CLAMESettings::OnTypeChanged()
{
}


void CLAMESettings::OnVBRQualityChanged()
{
}


void CLAMESettings::OnChannelsChanged()
{
}


void CLAMESettings::OnSampleRateChanged()
{
}


void CLAMESettings::OnBitRateChanged()
{
}


void CLAMESettings::OnQualityChanged()
{
}


HRESULT CLAMESettings::LoadCombo(CComboBox& combo, int nFirstString, int nLastString)
{
	CString s;
	HMODULE selfModule = AfxGetInstanceHandle();

	// Delete every item from the combo box. 
	for (int i = combo.GetCount() - 1; i >= 0; i--) {
		combo.DeleteString(i);
	}

	// Fill the combo box
	for (int i = nFirstString; i <= nLastString; ++i)
	{
		if (!s.LoadString(selfModule, i))
			return E_FAIL;
		combo.AddString(s);
	}

	// Select the first item
	combo.SetCurSel(0);

	return S_OK;
}
